BoundingBoxData class

Normalized bounding box guide (all values 0–1 in video space).

Constructors

BoundingBoxData({required double x, required double y, required double width, required double height, required double videoAspect})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoAspect double
Video width / height (e.g. 4/3 for 960×720).
final
width double
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited