RepData class

Per-rep detail data (mirrors native RepData).

Constructors

RepData({String detectionStartTime = '', String detectionEndTime = '', bool isShallowRep = false, bool isGood = false, double romScore = 0, double techniqueScore = 0, List<String>? feedback})
const

Properties

detectionEndTime String
final
detectionStartTime String
final
feedback List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
isGood bool
final
isShallowRep bool
final
romScore double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
techniqueScore double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map? map) RepData