DetectionSessionResultData class
Session summary (mirrors native DetectionSessionResultData).
Constructors
-
DetectionSessionResultData({String sessionId = '', List<
SMExerciseInfo> exercises = const [], String startDate = '', String endDate = '', String totalTime = '', int totalScore = 0}) -
const
Properties
- endDate → String
-
final
-
exercises
→ List<
SMExerciseInfo> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- startDate → String
-
final
- totalScore → int
-
final
- totalTime → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map? map) → DetectionSessionResultData