SessionSettings class
Session configuration for SMKit (mirrors native SMKitSessionSettings).
Constructors
Properties
- configFileName → String?
-
final
- enableBodyCalibration → bool
-
final
- enablePhoneCalibration → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- include3D → bool
-
final
- jumpHeightThreshold → int
-
final
- jumpRefPoint → String
-
final
- phonePosition → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userHeight → double
-
final
- verboseBodyCalibration → bool
-
When true, enables verbose body calibration logging on iOS (e.g. frame size, joint detection). Android ignores this.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map? map) → SessionSettings