SmKit class
Flutter API for Sency SMKit (no-UI): session/detection lifecycle and data streams.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
sessionEventStream
→ Stream<
SmKitSessionEvent> -
Stream of session events: detection data, position data, errors, camera ready/stopped.
no setter
Static Methods
-
configure(
{required String authKey, bool support3D = false, SmKitPoseModelChoice poseModelChoice = SmKitPoseModelChoice.adaptiveChoice}) → Future< void> - One-time SDK configuration. Call before starting a session.
-
setConfigString(
String? configString) → Future< void> - Set a config string outside of detection context.
-
setFeedbacksToExclude(
Set< String> feedbacks) → Future<void> - Set feedback types to exclude from detection results.
-
startDetection(
{required String exercise, String? configString}) → Future< DetectionStartResult?> - Start exercise detection (e.g. "SquatRegular", "PlankHighStatic"). Returns ROM range and exercise type if available.
-
startSession(
{required int viewId, required SessionSettings settings}) → Future< void> -
Start camera/session.
viewIdmust be the id of an SmKitCameraView already built. -
stopCamera(
) → Future< void> - Stop the camera without ending the detection session.
-
stopDetection(
) → Future< SMExerciseInfo> - Stop current detection and return exercise result.
-
stopSession(
) → Future< DetectionSessionResultData?> - Stop session and return session result.