SmKitSessionEvent class

A single event from the session stream.

Constructors

SmKitSessionEvent({required SmKitSessionEventType type, MovementFeedbackData? detectionData, Map<String, dynamic>? positionData, BodyCalibrationData? calibrationData, bool? isPhoneReady, BoundingBoxData? boundingBox, double? frameAspect, String? errorCode, String? errorMessage})
const

Properties

boundingBox BoundingBoxData?
Set on SmKitSessionEventType.boundingBox events.
final
calibrationData BodyCalibrationData?
final
detectionData MovementFeedbackData?
final
errorCode String?
final
errorMessage String?
final
frameAspect double?
Frame aspect ratio (width/height) sent from Android with positionData events.
final
hashCode int
The hash code for this object.
no setterinherited
isPhoneReady bool?
Set on SmKitSessionEventType.phoneCalibration events.
final
positionData Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SmKitSessionEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map? map) SmKitSessionEvent